@@ -1,14 +1,18 @@
+import logging
 import requests
+
 from django.conf import settings
 from django import forms
 from dateutil.parser import parse
-from crispy_forms.layout import Layout, Div, HTML
+from crispy_forms.layout import Div, HTML
 from astropy import units as u
 
 from tom_observations.facility import BaseRoboticObservationFacility, BaseRoboticObservationForm
 from tom_common.exceptions import ImproperCredentialsException
 from tom_targets.models import Target
 
+logger = logging.getLogger(__name__)
+
 try:
     GEM_SETTINGS = settings.FACILITIES['GEM']
 except KeyError:
@@ -35,6 +39,7 @@ except KeyError:
     }
 
 PORTAL_URL = GEM_SETTINGS['portal_url']
+VALID_OBSERVING_STATES = ['TRIGGERED', 'ON_HOLD']
 TERMINAL_OBSERVING_STATES = ['TRIGGERED', 'ON_HOLD']
 
 # Units of flux and wavelength for converting to Specutils Spectrum1D objects
@@ -60,7 +65,7 @@ SITES = {
 def make_request(*args, **kwargs):
     response = requests.request(*args, **kwargs)
     if 400 <= response.status_code < 500:
-        print('Request failed: {}'.format(response.content))
+        logger.log(msg=f'Gemini request failed: {response.content}', level=logging.WARN)
         raise ImproperCredentialsException('GEM')
     response.raise_for_status()
     return response
@@ -140,6 +145,7 @@ class GEMObservationForm(BaseRoboticObservationForm):
     ra             - target RA [J2000], format 'HH:MM:SS.SS'
     dec            - target Dec[J2000], format 'DD:MM:SS.SSS'
     mags           - target magnitude information (optional)
+    noteTitle      - title for the note, "Finding Chart" if not provided (optional)
     note           - text to include in a "Finding Chart" note (optional)
     posangle       - position angle [degrees E of N], defaults to 0 (optional)
     exptime        - exposure time [seconds], if not given then value in template used (optional)
@@ -201,12 +207,14 @@ class GEMObservationForm(BaseRoboticObservationForm):
     # Form fields
     obsid = forms.MultipleChoiceField(choices=obs_choices())
     ready = forms.ChoiceField(initial='true', choices=(('true', 'Yes'), ('false', 'No')))
-    brightness = forms.FloatField(required=False, label='Target brightness')
+    brightness = forms.FloatField(required=False, label='Target Brightness')
     brightness_system = forms.ChoiceField(required=False,
                                           initial='AB',
+                                          label='Brightness System',
                                           choices=(('Vega', 'Vega'), ('AB', 'AB'), ('Jy', 'Jy')))
     brightness_band = forms.ChoiceField(required=False,
                                         initial='r',
+                                        label='Brightness Band',
                                         choices=(('u', 'u'), ('U', 'U'), ('B', 'B'), ('g', 'g'), ('V', 'V'),
                                                  ('UC', 'UC'), ('r', 'r'), ('R', 'R'), ('i', 'i'), ('I', 'I'),
                                                  ('z', 'z'), ('Y', 'Y'), ('J', 'J'), ('H', 'H'), ('K', 'K'),
@@ -215,12 +223,13 @@ class GEMObservationForm(BaseRoboticObservationForm):
                                 max_value=360.,
                                 required=False,
                                 initial=0.0,
-                                label='Position Angle in degrees [0-360]')
+                                label='Position Angle [0-360]')
 
-    exptimes = forms.CharField(required=False, label='Exptime [sec]. If multiple, comma separate')
+    exptimes = forms.CharField(required=False, label='Exptime [s], comma separate')
 
-    group = forms.CharField(required=False)
-    note = forms.CharField(required=False)
+    group = forms.CharField(required=False, label='Group Name')
+    notetitle = forms.CharField(required=False, initial='Finding Chart', label='Note Title')
+    note = forms.CharField(required=False, label='Note Text')
 
     eltype = forms.ChoiceField(required=False, label='Airmass/Hour Angle Constraint',
                                choices=(('none', 'None'), ('airmass', 'Airmass'), ('hourAngle', 'Hour Angle')))
@@ -250,12 +259,16 @@ class GEMObservationForm(BaseRoboticObservationForm):
                                          ('PWFS2', 'PWFS2'),
                                          ('AOWFS', 'AOWFS')))  # GS probe (PWFS1/PWFS2/OIWFS/AOWFS)
     window_start = forms.CharField(required=False, widget=forms.TextInput(attrs={'type': 'date'}),
-                                   label='UT Timing Window Start [Date Time]')
+                                   label='Timing Window [Date Time]')
     window_duration = forms.IntegerField(required=False, min_value=1, label='Timing Window Duration [hr]')
 
     def layout(self):
         return Div(
             HTML('<big>Observation Parameters</big>'),
+            HTML('<p>Select the Obsids of one or more templates. <br>'),
+            HTML('Setting Ready=No will keep the new observation(s) On Hold. <br>'),
+            HTML('If a value is not set, then the template default is used. <br>'),
+            HTML('If setting Exptime, then provide a list of values if selecting more than one Obsid.</p>'),
             Div(
                 Div(
                     'obsid',
@@ -266,27 +279,28 @@ class GEMObservationForm(BaseRoboticObservationForm):
                     css_class='col'
                 ),
                 Div(
-                    'group',
+                    'notetitle',
                     css_class='col'
                 ),
                 css_class='form-row'
             ),
             Div(
                 Div(
-                    'posangle', 'brightness', 'eltype', 'window_start',
+                    'posangle', 'brightness', 'eltype', 'group',
                     css_class='col'
                 ),
                 Div(
-                    'exptimes', 'brightness_band', 'elmin', 'window_duration',
+                    'exptimes', 'brightness_band', 'elmin', 'window_start',
                     css_class='col'
                 ),
                 Div(
-                    'note', 'brightness_system', 'elmax',
+                    'note', 'brightness_system', 'elmax', 'window_duration',
                     css_class='col'
                 ),
                 css_class='form-row'
             ),
-            HTML('<big>Optional Guide Star Parameters: If any one of Name/RA/Dec is given, then all must be.</big>'),
+            HTML('<big>Optional Guide Star Parameters</big>'),
+            HTML('<p>If any one of Name/RA/Dec is given, then all must be.</p>'),
             Div(
                 Div(
                     'gstarg', 'gsbrightness', 'gsprobe',
@@ -348,18 +362,19 @@ class GEMObservationForm(BaseRoboticObservationForm):
             obsnum = obs[ii+1:]
             payload = {
                 "prog": progid,
-                # "password": self.cleaned_data['userkey'],
                 "password": GEM_SETTINGS['api_key'][get_site(obs)],
-                # "email": self.cleaned_data['email'],
                 "email": GEM_SETTINGS['user_email'],
                 "obsnum": obsnum,
                 "target": target.name,
                 "ra": target.ra,
                 "dec": target.dec,
-                "note": self.cleaned_data['note'],
                 "ready": self.cleaned_data['ready']
             }
 
+            if self.cleaned_data['notetitle'] != 'Finding Chart' or self.cleaned_data['note'] != '':
+                payload["noteTitle"] = self.cleaned_data['notetitle']
+                payload["note"] = self.cleaned_data['note']
+
             if self.cleaned_data['brightness'] is not None:
                 smags = str(self.cleaned_data['brightness']).strip() + '/' + \
                     self.cleaned_data['brightness_band'] + '/' + \
@@ -412,11 +427,13 @@ class GEMObservationForm(BaseRoboticObservationForm):
 class GEMFacility(BaseRoboticObservationFacility):
     """
     The ``GEMFacility`` is the interface to the Gemini Telescope. For information regarding Gemini observing and the
-    available parameters, please see https://www.gemini.edu/sciops/observing-gemini.
+    available parameters, please see https://www.gemini.edu/observing/start-here
     """
 
     name = 'GEM'
-    observation_types = [('OBSERVATION', 'Gemini Observation')]
+    observation_forms = {
+        'OBSERVATION': GEMObservationForm
+    }
 
     def get_form(self, observation_type):
         return GEMObservationForm
