@@ -3,7 +3,7 @@ import requests
 
 from astropy import units as u
 from crispy_forms.bootstrap import AppendedText, PrependedText
-from crispy_forms.layout import Column, Div, HTML, Layout, Row
+from crispy_forms.layout import Column, Div, HTML, Layout, Row, MultiWidgetField, Fieldset
 from dateutil.parser import parse
 from django import forms
 from django.conf import settings
@@ -27,6 +27,9 @@ except (AttributeError, KeyError):
 
 # Module specific settings.
 PORTAL_URL = LCO_SETTINGS['portal_url']
+# Valid observing states at LCO are defined here: https://developers.lco.global/#data-format-definition
+VALID_OBSERVING_STATES = ['PENDING', 'COMPLETED', 'WINDOW_EXPIRED', 'CANCELED']
+PENDING_OBSERVING_STATES = ['PENDING']
 SUCCESSFUL_OBSERVING_STATES = ['COMPLETED']
 FAILED_OBSERVING_STATES = ['WINDOW_EXPIRED', 'CANCELED']
 TERMINAL_OBSERVING_STATES = SUCCESSFUL_OBSERVING_STATES + FAILED_OBSERVING_STATES
@@ -46,7 +49,7 @@ ipp_value_help = """
         Value between 0.5 to 2.0.
         <a href="https://lco.global/documents/20/the_new_priority_factor.pdf">
             More information about Intra Proprosal Priority (IPP).
-        </a>.
+        </a>
 """
 
 observation_mode_help = """
@@ -82,6 +85,19 @@ max_airmass_help = """
     </a>
 """
 
+static_cadencing_help = """
+    Static cadence parameters. Leave blank if no cadencing is desired.
+    For information on static cadencing with LCO,
+    <a href="https://lco.global/documentation/">
+        check the Observation Portal getting started guide, starting on page 18.
+    </a>
+"""
+
+muscat_exposure_mode_help = """
+    Synchronous syncs the start time of exposures on all 4 cameras while asynchronous takes
+    exposures as quickly as possible on each camera.
+"""
+
 
 def make_request(*args, **kwargs):
     response = requests.request(*args, **kwargs)
@@ -103,7 +119,8 @@ class LCOBaseForm(forms.Form):
         self.fields['filter'] = forms.ChoiceField(choices=self.filter_choices())
         self.fields['instrument_type'] = forms.ChoiceField(choices=self.instrument_choices())
 
-    def _get_instruments(self):
+    @staticmethod
+    def _get_instruments():
         cached_instruments = cache.get('lco_instruments')
 
         if not cached_instruments:
@@ -117,16 +134,19 @@ class LCOBaseForm(forms.Form):
 
         return cached_instruments
 
-    def instrument_choices(self):
-        return sorted([(k, v['name']) for k, v in self._get_instruments().items()], key=lambda inst: inst[1])
+    @staticmethod
+    def instrument_choices():
+        return sorted([(k, v['name']) for k, v in LCOBaseForm._get_instruments().items()], key=lambda inst: inst[1])
 
-    def filter_choices(self):
+    @staticmethod
+    def filter_choices():
         return sorted(set([
-            (f['code'], f['name']) for ins in self._get_instruments().values() for f in
+            (f['code'], f['name']) for ins in LCOBaseForm._get_instruments().values() for f in
             ins['optical_elements'].get('filters', []) + ins['optical_elements'].get('slits', [])
             ]), key=lambda filter_tuple: filter_tuple[1])
 
-    def proposal_choices(self):
+    @staticmethod
+    def proposal_choices():
         response = make_request(
             'GET',
             PORTAL_URL + '/api/profile/',
@@ -139,7 +159,7 @@ class LCOBaseForm(forms.Form):
         return choices
 
 
-class LCOBaseObservationForm(BaseRoboticObservationForm, LCOBaseForm, CadenceForm):
+class LCOBaseObservationForm(BaseRoboticObservationForm, LCOBaseForm):
     """
     The LCOBaseObservationForm provides the base set of utilities to construct an observation at Las Cumbres
     Observatory. While the forms that inherit from it provide a subset of instruments and filters, the
@@ -158,7 +178,7 @@ class LCOBaseObservationForm(BaseRoboticObservationForm, LCOBaseForm, CadenceFor
     exposure_time = forms.FloatField(min_value=0.1,
                                      widget=forms.TextInput(attrs={'placeholder': 'Seconds'}),
                                      help_text=exposure_time_help)
-    max_airmass = forms.FloatField(help_text=max_airmass_help)
+    max_airmass = forms.FloatField(help_text=max_airmass_help, min_value=0)
     min_lunar_distance = forms.IntegerField(min_value=0, label='Minimum Lunar Distance', required=False)
     period = forms.FloatField(required=False)
     jitter = forms.FloatField(required=False)
@@ -172,9 +192,10 @@ class LCOBaseObservationForm(BaseRoboticObservationForm, LCOBaseForm, CadenceFor
         self.helper.layout = Layout(
             self.common_layout,
             self.layout(),
-            self.cadence_layout,
             self.button_layout()
         )
+        if isinstance(self, CadenceForm):
+            self.helper.layout.insert(2, self.cadence_layout())
 
     def layout(self):
         return Div(
@@ -190,7 +211,7 @@ class LCOBaseObservationForm(BaseRoboticObservationForm, LCOBaseForm, CadenceFor
                 css_class='form-row',
             ),
             Div(
-                HTML('<p>Cadence parameters. Leave blank if no cadencing is desired.</p>'),
+                HTML(f'''<br/><p>{static_cadencing_help}</p>'''),
             ),
             Div(
                 Div(
@@ -213,13 +234,16 @@ class LCOBaseObservationForm(BaseRoboticObservationForm, LCOBaseForm, CadenceFor
         end = self.cleaned_data['end']
         return parse(end).isoformat()
 
-    def is_valid(self):
-        super().is_valid()
+    def validate_at_facility(self):
         obs_module = get_service_class(self.cleaned_data['facility'])
         errors = obs_module().validate_observation(self.observation_payload())
         if errors:
             self.add_error(None, self._flatten_error_dict(errors))
-        return not errors
+
+    def is_valid(self):
+        super().is_valid()
+        self.validate_at_facility()
+        return not self._errors
 
     def _flatten_error_dict(self, error_dict):
         non_field_errors = []
@@ -243,7 +267,8 @@ class LCOBaseObservationForm(BaseRoboticObservationForm, LCOBaseForm, CadenceFor
 
         return non_field_errors
 
-    def instrument_to_type(self, instrument_type):
+    @staticmethod
+    def instrument_to_type(instrument_type):
         if 'FLOYDS' in instrument_type:
             return 'SPECTRUM'
         elif 'NRES' in instrument_type:
@@ -342,21 +367,21 @@ class LCOBaseObservationForm(BaseRoboticObservationForm, LCOBaseForm, CadenceFor
 
     def observation_payload(self):
         payload = {
-            "name": self.cleaned_data['name'],
-            "proposal": self.cleaned_data['proposal'],
-            "ipp_value": self.cleaned_data['ipp_value'],
-            "operator": "SINGLE",
-            "observation_type": self.cleaned_data['observation_mode'],
-            "requests": [
+            'name': self.cleaned_data['name'],
+            'proposal': self.cleaned_data['proposal'],
+            'ipp_value': self.cleaned_data['ipp_value'],
+            'operator': 'SINGLE',
+            'observation_type': self.cleaned_data['observation_mode'],
+            'requests': [
                 {
-                    "configurations": [self._build_configuration()],
-                    "windows": [
+                    'configurations': [self._build_configuration()],
+                    'windows': [
                         {
-                            "start": self.cleaned_data['start'],
-                            "end": self.cleaned_data['end']
+                            'start': self.cleaned_data['start'],
+                            'end': self.cleaned_data['end']
                         }
                     ],
-                    "location": self._build_location()
+                    'location': self._build_location()
                 }
             ]
         }
@@ -371,17 +396,200 @@ class LCOImagingObservationForm(LCOBaseObservationForm):
     The LCOImagingObservationForm allows the selection of parameters for observing using LCO's Imagers. The list of
     Imagers and their details can be found here: https://lco.global/observatory/instruments/
     """
-    def instrument_choices(self):
-        return sorted([(k, v['name']) for k, v in self._get_instruments().items() if 'IMAGE' in v['type']],
-                      key=lambda inst: inst[1])
+    @staticmethod
+    def instrument_choices():
+        # Support for the Muscat instrument is provided by a different form, so exclude it here.
+        return sorted(
+            [
+                (k, v['name']) for k, v in LCOImagingObservationForm._get_instruments().items()
+                if 'IMAGE' in v['type'] and 'MUSCAT' not in k
+            ],
+            key=lambda inst: inst[1]
+        )
 
-    def filter_choices(self):
+    @staticmethod
+    def filter_choices():
         return sorted(set([
-            (f['code'], f['name']) for ins in self._get_instruments().values() for f in
+            (f['code'], f['name']) for ins in LCOImagingObservationForm._get_instruments().values() for f in
             ins['optical_elements'].get('filters', [])
             ]), key=lambda filter_tuple: filter_tuple[1])
 
 
+class LCOMuscatImagingObservationForm(LCOBaseObservationForm):
+    """
+    The LCOMuscatImagingObservationForm allows the selection of parameter for observing using LCO's Muscat imaging
+    instrument. More information can be found here: https://lco.global/observatory/instruments/muscat3/
+    """
+    exposure_time_g = forms.FloatField(min_value=0, label='g')
+    exposure_time_r = forms.FloatField(min_value=0, label='r')
+    exposure_time_i = forms.FloatField(min_value=0, label='i')
+    exposure_time_z = forms.FloatField(min_value=0, label='z')
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        # `filter` and `exposure_time` are in the parent form but the Muscat form does not need them
+        self.fields.pop('filter', None)
+        self.fields.pop('exposure_time', None)
+        self.fields['guider_mode'] = forms.ChoiceField(choices=self.mode_choices('guiding'))
+        self.fields['exposure_mode'] = forms.ChoiceField(
+            choices=self.mode_choices('exposure'),
+            help_text=muscat_exposure_mode_help
+        )
+        self.fields['diffuser_g_position'] = forms.ChoiceField(
+            choices=self.diffuser_position_choices(channel='g'),
+            label='g'
+        )
+        self.fields['diffuser_r_position'] = forms.ChoiceField(
+            choices=self.diffuser_position_choices(channel='r'),
+            label='r'
+        )
+        self.fields['diffuser_i_position'] = forms.ChoiceField(
+            choices=self.diffuser_position_choices(channel='i'),
+            label='i'
+        )
+        self.fields['diffuser_z_position'] = forms.ChoiceField(
+            choices=self.diffuser_position_choices(channel='z'),
+            label='z'
+        )
+
+    def layout(self):
+        return Div(
+            Div(
+                Div(
+                    'name', 'proposal', 'ipp_value', 'observation_mode', 'start', 'end',
+                    css_class='col'
+                ),
+                Div(
+                    'instrument_type', 'guider_mode', 'exposure_mode', 'exposure_count', 'max_airmass',
+                    'min_lunar_distance',
+                    css_class='col'
+                ),
+                css_class='form-row',
+            ),
+            Fieldset(
+                'Diffuser Positions',
+                HTML('''<p>Select the diffuser position for each channel.</p>'''),
+                Div(
+                    Div(
+                        'diffuser_g_position',
+                        css_class='col'
+                    ),
+                    Div(
+                        'diffuser_r_position',
+                        css_class='col'
+                    ),
+                    Div(
+                        'diffuser_i_position',
+                        css_class='col'
+                    ),
+                    Div(
+                        'diffuser_z_position',
+                        css_class='col'
+                    ),
+                    css_class='form-row'
+                )
+            ),
+            Fieldset(
+                'Exposure Times',
+                HTML('''<p>Set an exposure time for each channel.</p>'''),
+                Div(
+                    Div(
+                        'exposure_time_g',
+                        css_class='col'
+                    ),
+                    Div(
+                        'exposure_time_r',
+                        css_class='col'
+                    ),
+                    Div(
+                        'exposure_time_i',
+                        css_class='col'
+                    ),
+                    Div(
+                        'exposure_time_z',
+                        css_class='col'
+                    ),
+                    css_class='form-row'
+                )
+            ),
+            Fieldset(
+                'Cadence',
+                HTML(f'''<p>{static_cadencing_help}</p>'''),
+                Div(
+                    Div(
+                        'period',
+                        css_class='col'
+                    ),
+                    Div(
+                        'jitter',
+                        css_class='col'
+                    ),
+                    css_class='form-row'
+                )
+            )
+        )
+
+    @staticmethod
+    def _get_muscat_instrument():
+        all_instruments = LCOMuscatImagingObservationForm._get_instruments()
+        return {k: v for k, v in all_instruments.items() if 'MUSCAT' in k and 'IMAGE' in v['type']}
+
+    @staticmethod
+    def instrument_choices():
+        return sorted([
+            (k, v['name']) for k, v in LCOMuscatImagingObservationForm._get_muscat_instrument().items()],
+            key=lambda inst: inst[1]
+        )
+
+    @staticmethod
+    def mode_choices(mode_type):
+        return sorted(set([
+            (f['code'], f['name']) for ins in LCOMuscatImagingObservationForm._get_muscat_instrument().values() for f in
+            ins['modes'].get(mode_type, {}).get('modes', [])
+            ]), key=lambda filter_tuple: filter_tuple[1])
+
+    @staticmethod
+    def diffuser_position_choices(channel):
+        diffuser_key = f'diffuser_{channel}_positions'
+        return sorted(set([
+            (f['code'], f['name']) for ins in LCOMuscatImagingObservationForm._get_muscat_instrument().values() for f in
+            ins['optical_elements'].get(diffuser_key, []) if f.get('schedulable', False)
+        ]), key=lambda filter_tuple: filter_tuple[1])
+
+    def _build_guiding_config(self):
+        guiding_config = super()._build_guiding_config()
+        guiding_config['mode'] = self.cleaned_data['guider_mode']
+        # Muscat guiding `optional` setting only makes sense set to true from the telescope software perspective
+        guiding_config['optional'] = True
+        return guiding_config
+
+    def _build_instrument_config(self):
+        # Refer to the 'MUSCAT instrument configuration' section on this page: https://developers.lco.global/
+        instrument_config = {
+            'exposure_count': self.cleaned_data['exposure_count'],
+            'exposure_time': max(
+                self.cleaned_data['exposure_time_g'],
+                self.cleaned_data['exposure_time_r'],
+                self.cleaned_data['exposure_time_i'],
+                self.cleaned_data['exposure_time_z']
+            ),
+            'optical_elements': {
+                'diffuser_g_position': self.cleaned_data['diffuser_g_position'],
+                'diffuser_r_position': self.cleaned_data['diffuser_r_position'],
+                'diffuser_i_position': self.cleaned_data['diffuser_i_position'],
+                'diffuser_z_position': self.cleaned_data['diffuser_z_position']
+            },
+            'extra_params': {
+                'exposure_mode': self.cleaned_data['exposure_mode'],
+                'exposure_time_g': self.cleaned_data['exposure_time_g'],
+                'exposure_time_r': self.cleaned_data['exposure_time_r'],
+                'exposure_time_i': self.cleaned_data['exposure_time_i'],
+                'exposure_time_z': self.cleaned_data['exposure_time_z'],
+            }
+        }
+        return [instrument_config]
+
+
 class LCOSpectroscopyObservationForm(LCOBaseObservationForm):
     """
     The LCOSpectroscopyObservationForm allows the selection of parameters for observing using LCO's Spectrographs. The
@@ -421,14 +629,19 @@ class LCOSpectroscopyObservationForm(LCOBaseObservationForm):
             )
         )
 
-    def instrument_choices(self):
-        return sorted([(k, v['name']) for k, v in self._get_instruments().items() if 'SPECTRA' in v['type']],
-                      key=lambda inst: inst[1])
+    @staticmethod
+    def instrument_choices():
+        return sorted(
+            [(k, v['name'])
+             for k, v in LCOSpectroscopyObservationForm._get_instruments().items()
+             if 'SPECTRA' in v['type']],
+            key=lambda inst: inst[1])
 
     # NRES does not take a slit, and therefore needs an option of None
-    def filter_choices(self):
+    @staticmethod
+    def filter_choices():
         return sorted(set([
-            (f['code'], f['name']) for ins in self._get_instruments().values() for f in
+            (f['code'], f['name']) for ins in LCOSpectroscopyObservationForm._get_instruments().values() for f in
             ins['optical_elements'].get('slits', [])
             ] + [('None', 'None')]),
             key=lambda filter_tuple: filter_tuple[1])
@@ -457,10 +670,7 @@ class LCOPhotometricSequenceForm(LCOBaseObservationForm):
     """
     valid_instruments = ['1M0-SCICAM-SINISTRO', '0M4-SCICAM-SBIG', '2M0-SPECTRAL-AG']
     filters = ['U', 'B', 'V', 'R', 'I', 'u', 'g', 'r', 'i', 'z', 'w']
-    cadence_type = forms.ChoiceField(
-        choices=[('once', 'Once in the next'), ('repeat', 'Repeating every')],
-        required=True
-    )
+    cadence_frequency = forms.IntegerField(required=True, help_text='in hours')
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -470,12 +680,10 @@ class LCOPhotometricSequenceForm(LCOBaseObservationForm):
             self.fields[filter_name] = FilterField(label=filter_name, required=False)
 
         # Massage cadence form to be SNEx-styled
-        self.fields['cadence_strategy'].widget = forms.HiddenInput()
-        self.fields['cadence_strategy'].required = False
-        self.fields['cadence_frequency'].required = True
-        self.fields['cadence_frequency'].widget.attrs['readonly'] = False
-        self.fields['cadence_frequency'].widget.attrs['help_text'] = 'in hours'
-
+        self.fields['cadence_strategy'] = forms.ChoiceField(
+            choices=[('', 'Once in the next'), ('ResumeCadenceAfterFailureStrategy', 'Repeating every')],
+            required=False,
+        )
         for field_name in ['exposure_time', 'exposure_count', 'start', 'end', 'filter']:
             self.fields.pop(field_name)
         if self.fields.get('groups'):
@@ -484,7 +692,7 @@ class LCOPhotometricSequenceForm(LCOBaseObservationForm):
         self.helper.layout = Layout(
             Div(
                 Column('name'),
-                Column('cadence_type'),
+                Column('cadence_strategy'),
                 Column('cadence_frequency'),
                 css_class='form-row'
             ),
@@ -523,19 +731,20 @@ class LCOPhotometricSequenceForm(LCOBaseObservationForm):
         """
         cleaned_data = super().clean()
         now = datetime.now()
-        cleaned_data['start'] = datetime.strftime(datetime.now(), '%Y-%m-%dT%H:%M:%S')
+        cleaned_data['start'] = datetime.strftime(now, '%Y-%m-%dT%H:%M:%S')
         cleaned_data['end'] = datetime.strftime(now + timedelta(hours=cleaned_data['cadence_frequency']),
                                                 '%Y-%m-%dT%H:%M:%S')
-        if cleaned_data['cadence_type'] == 'repeat':
-            cleaned_data['cadence_strategy'] = 'Resume Cadence After Failure'
 
         return cleaned_data
 
-    def instrument_choices(self):
+    @staticmethod
+    def instrument_choices():
         """
         This method returns only the instrument choices available in the current SNEx photometric sequence form.
         """
-        return sorted([(k, v['name']) for k, v in self._get_instruments().items() if k in self.valid_instruments],
+        return sorted([(k, v['name'])
+                       for k, v in LCOPhotometricSequenceForm._get_instruments().items()
+                       if k in LCOPhotometricSequenceForm.valid_instruments],
                       key=lambda inst: inst[1])
 
     def cadence_layout(self):
@@ -560,7 +769,7 @@ class LCOPhotometricSequenceForm(LCOBaseObservationForm):
             )
         )
         for filter_name in self.filters:
-            filter_layout.append(Row(filter_name))
+            filter_layout.append(Row(MultiWidgetField(filter_name, attrs={'min': 0})))
 
         return Div(
             Div(
@@ -585,14 +794,11 @@ class LCOPhotometricSequenceForm(LCOBaseObservationForm):
 
 class LCOSpectroscopicSequenceForm(LCOBaseObservationForm):
     site = forms.ChoiceField(choices=(('any', 'Any'), ('ogg', 'Hawaii'), ('coj', 'Australia')))
-    acquisition_radius = forms.FloatField(min_value=0)
+    acquisition_radius = forms.FloatField(min_value=0, required=False)
     guider_mode = forms.ChoiceField(choices=[('on', 'On'), ('off', 'Off'), ('optional', 'Optional')], required=True)
     guider_exposure_time = forms.IntegerField(min_value=0)
-    cadence_type = forms.ChoiceField(
-        choices=[('once', 'Once in the next'), ('repeat', 'Repeating every')],
-        required=True,
-        label=''
-    )
+    cadence_frequency = forms.IntegerField(required=True,
+                                           widget=forms.NumberInput(attrs={'placeholder': 'Hours'}))
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -601,13 +807,12 @@ class LCOSpectroscopicSequenceForm(LCOBaseObservationForm):
         self.fields['name'].label = ''
         self.fields['name'].widget.attrs['placeholder'] = 'Name'
         self.fields['min_lunar_distance'].widget.attrs['placeholder'] = 'Degrees'
-        self.fields['cadence_strategy'].widget = forms.HiddenInput()
-        self.fields['cadence_strategy'].required = False
-        self.fields['cadence_frequency'].required = True
+        self.fields['cadence_strategy'] = forms.ChoiceField(
+            choices=[('', 'Once in the next'), ('ResumeCadenceAfterFailureStrategy', 'Repeating every')],
+            required=False,
+            label=''
+        )
         self.fields['cadence_frequency'].label = ''
-        self.fields['cadence_frequency'].widget.attrs['readonly'] = False
-        self.fields['cadence_frequency'].widget.attrs['placeholder'] = 'Hours'
-        self.fields['cadence_frequency'].help_text = None
 
         # Remove start and end because those are determined by the cadence
         for field_name in ['start', 'end']:
@@ -618,7 +823,7 @@ class LCOSpectroscopicSequenceForm(LCOBaseObservationForm):
         self.helper.layout = Layout(
             Div(
                 Column('name'),
-                Column('cadence_type'),
+                Column('cadence_strategy'),
                 Column(AppendedText('cadence_frequency', 'Hours')),
                 css_class='form-row'
             ),
@@ -637,13 +842,13 @@ class LCOSpectroscopicSequenceForm(LCOBaseObservationForm):
     def _build_acquisition_config(self):
         acquisition_config = super()._build_acquisition_config()
         # SNEx uses WCS mode if no acquisition radius is specified, and BRIGHTEST otherwise
-        acquisition_mode = 'BRIGHTEST'
         if not self.cleaned_data['acquisition_radius']:
-            acquisition_mode = 'WCS'
-        acquisition_config['mode'] = acquisition_mode
-        acquisition_config['extra_params'] = {
-            'acquire_radius': self.cleaned_data['acquisition_radius']
-        }
+            acquisition_config['mode'] = 'WCS'
+        else:
+            acquisition_config['mode'] = 'BRIGHTEST'
+            acquisition_config['extra_params'] = {
+                'acquire_radius': self.cleaned_data['acquisition_radius']
+            }
 
         return acquisition_config
 
@@ -676,20 +881,22 @@ class LCOSpectroscopicSequenceForm(LCOBaseObservationForm):
         cleaned_data['start'] = datetime.strftime(datetime.now(), '%Y-%m-%dT%H:%M:%S')
         cleaned_data['end'] = datetime.strftime(now + timedelta(hours=cleaned_data['cadence_frequency']),
                                                 '%Y-%m-%dT%H:%M:%S')
-        if cleaned_data['cadence_type'] == 'repeat':
-            cleaned_data['cadence_strategy'] = 'Resume Cadence After Failure'
 
         return cleaned_data
 
-    def instrument_choices(self):
+    @staticmethod
+    def instrument_choices():
         # SNEx only uses the Spectroscopic Sequence Form with FLOYDS
         # This doesn't need to be sorted because it will only return one instrument
-        return [(k, v['name']) for k, v in self._get_instruments().items() if k == '2M0-FLOYDS-SCICAM']
+        return [(k, v['name'])
+                for k, v in LCOSpectroscopicSequenceForm._get_instruments().items()
+                if k == '2M0-FLOYDS-SCICAM']
 
-    def filter_choices(self):
+    @staticmethod
+    def filter_choices():
         # SNEx only uses the Spectroscopic Sequence Form with FLOYDS
         return sorted(set([
-            (f['code'], f['name']) for name, ins in self._get_instruments().items() for f in
+            (f['code'], f['name']) for name, ins in LCOSpectroscopicSequenceForm._get_instruments().items() for f in
             ins['optical_elements'].get('slits', []) if name == '2M0-FLOYDS-SCICAM'
             ]), key=lambda filter_tuple: filter_tuple[1])
 
@@ -752,8 +959,10 @@ class LCOFacility(BaseRoboticObservationFacility):
     """
 
     name = 'LCO'
+    # TODO: make the keys the display values instead
     observation_forms = {
         'IMAGING': LCOImagingObservationForm,
+        'MUSCAT_IMAGING': LCOMuscatImagingObservationForm,
         'SPECTRA': LCOSpectroscopyObservationForm,
         'PHOTOMETRIC_SEQUENCE': LCOPhotometricSequenceForm,
         'SPECTROSCOPIC_SEQUENCE': LCOSpectroscopicSequenceForm
@@ -802,9 +1011,11 @@ class LCOFacility(BaseRoboticObservationFacility):
         }
     }
 
+    # TODO: this should be called get_form_class
     def get_form(self, observation_type):
         return self.observation_forms.get(observation_type, LCOBaseObservationForm)
 
+    # TODO: this should be called get_template_form_class
     def get_template_form(self, observation_type):
         return LCOObservationTemplateForm
 
