@@ -5,9 +5,10 @@ from unittest.mock import patch
 from datetime import datetime, timedelta
 from dateutil.parser import parse
 
-from .factories import ObservingRecordFactory, TargetFactory
+from .factories import ObservingRecordFactory, SiderealTargetFactory
 from tom_observations.models import ObservationGroup, DynamicCadence
-from tom_observations.cadence import RetryFailedObservationsStrategy, ResumeCadenceAfterFailureStrategy
+from tom_observations.cadences.resume_cadence_after_failure import ResumeCadenceAfterFailureStrategy
+from tom_observations.cadences.retry_failed_observations import RetryFailedObservationsStrategy
 
 
 mock_filters = {'1M0-SCICAM-SINISTRO': {
@@ -43,7 +44,7 @@ obs_params = {
 @patch('tom_observations.facilities.lco.LCOFacility.validate_observation')
 class TestReactiveCadencing(TestCase):
     def setUp(self):
-        target = TargetFactory.create()
+        target = SiderealTargetFactory.create()
         obs_params['target_id'] = target.id
         observing_records = ObservingRecordFactory.create_batch(5,
                                                                 target_id=target.id,
@@ -51,9 +52,9 @@ class TestReactiveCadencing(TestCase):
         self.group = ObservationGroup.objects.create()
         self.group.observation_records.add(*observing_records)
         self.group.save()
-        # TODO: why doesn't this fail without cadence_strategy and name?
         self.dynamic_cadence = DynamicCadence.objects.create(
-            cadence_strategy='Test Strategy', cadence_parameters={}, active=True, observation_group=self.group)
+            cadence_strategy='Test Strategy', cadence_parameters={'cadence_frequency': 72}, active=True,
+            observation_group=self.group)
 
     def test_retry_when_failed_cadence(self, patch1, patch2, patch3, patch4):
         num_records = self.group.observation_records.count()
@@ -61,7 +62,7 @@ class TestReactiveCadencing(TestCase):
         observing_record.status = 'CANCELED'
         observing_record.save()
 
-        strategy = RetryFailedObservationsStrategy(self.dynamic_cadence, 72)
+        strategy = RetryFailedObservationsStrategy(self.dynamic_cadence)
         new_records = strategy.run()
         self.group.refresh_from_db()
         # Make sure the candence run created a new observation.
@@ -78,7 +79,7 @@ class TestReactiveCadencing(TestCase):
     def test_resume_when_failed_cadence_failed_obs(self, patch1, patch2, patch3, patch4, patch5):
         num_records = self.group.observation_records.count()
 
-        strategy = ResumeCadenceAfterFailureStrategy(self.dynamic_cadence, 72)
+        strategy = ResumeCadenceAfterFailureStrategy(self.dynamic_cadence)
         new_records = strategy.run()
         self.group.refresh_from_db()
         self.assertEqual(num_records + 1, self.group.observation_records.count())
@@ -93,7 +94,7 @@ class TestReactiveCadencing(TestCase):
         num_records = self.group.observation_records.count()
         observing_record = self.group.observation_records.order_by('-created').first()
 
-        strategy = ResumeCadenceAfterFailureStrategy(self.dynamic_cadence, 72)
+        strategy = ResumeCadenceAfterFailureStrategy(self.dynamic_cadence)
         new_records = strategy.run()
         self.group.refresh_from_db()
         self.assertEqual(num_records + 1, self.group.observation_records.count())
