@@ -9,10 +9,10 @@ from astroplan import FixedTarget
 from astropy.coordinates import get_sun, SkyCoord
 from astropy.time import Time
 
-from .factories import ObservingRecordFactory, ObservingStrategyFactory, TargetFactory, TargetNameFactory
+from .factories import ObservingRecordFactory, ObservationTemplateFactory, SiderealTargetFactory, TargetNameFactory
 from tom_observations.utils import get_astroplan_sun_and_time, get_sidereal_visibility
 from tom_observations.tests.utils import FakeRoboticFacility
-from tom_observations.models import ObservationRecord, ObservationGroup, ObservingStrategy
+from tom_observations.models import ObservationRecord, ObservationGroup, ObservationTemplate
 from tom_targets.models import Target
 from guardian.shortcuts import assign_perm
 
@@ -22,17 +22,17 @@ from guardian.shortcuts import assign_perm
                    TARGET_PERMISSIONS_ONLY=True)
 class TestObservationViews(TestCase):
     def setUp(self):
-        self.target = TargetFactory.create()
+        self.target = SiderealTargetFactory.create()
         self.target_name = TargetNameFactory.create(target=self.target)
         self.observation_record = ObservingRecordFactory.create(
             target_id=self.target.id,
             facility=FakeRoboticFacility.name,
             parameters='{}'
         )
-        user = User.objects.create_user(username='vincent_adultman', password='important')
+        self.user = User.objects.create_user(username='vincent_adultman', password='important')
         self.user2 = User.objects.create_user(username='peon', password='plebian')
-        assign_perm('tom_targets.view_target', user, self.target)
-        self.client.force_login(user)
+        assign_perm('tom_targets.view_target', self.user, self.target)
+        self.client.force_login(self.user)
 
     def test_observation_list(self):
         response = self.client.get(reverse('tom_observations:list'))
@@ -72,7 +72,7 @@ class TestObservationViews(TestCase):
 
     def test_get_observation_form(self):
         url = f"{reverse('tom_observations:create', kwargs={'facility': 'FakeRoboticFacility'})}" \
-              f"?target_id={self.target.id}"
+              f"?target_id={self.target.id}&observation_type=OBSERVATION"
         response = self.client.get(url)
         # self.assertContains(response, 'fake form input')
         self.assertContains(response, 'FakeRoboticFacility')
@@ -107,6 +107,7 @@ class TestObservationViews(TestCase):
             'target_id': self.target.id,
             'test_input': 'gnomes',
             'facility': 'FakeRoboticFacility',
+            'observation_type': 'OBSERVATION'
         }
         self.client.post(
             '{}?target_id={}'.format(
@@ -117,6 +118,7 @@ class TestObservationViews(TestCase):
             follow=True
         )
         self.assertTrue(ObservationRecord.objects.filter(observation_id='fakeid').exists())
+        self.assertEqual(ObservationRecord.objects.filter(observation_id='fakeid').first().user, self.user)
 
     def test_submit_observation_manual(self):
         form_data = {
@@ -128,13 +130,14 @@ class TestObservationViews(TestCase):
               f"?target_id={self.target.id}"
         self.client.post(url, data=form_data, follow=True)
         self.assertTrue(ObservationRecord.objects.filter(observation_id='fakeid').exists())
+        self.assertEqual(ObservationRecord.objects.filter(observation_id='fakeid').first().user, self.user)
 
 
 @override_settings(TOM_FACILITY_CLASSES=['tom_observations.tests.utils.FakeRoboticFacility'],
                    TARGET_PERMISSIONS_ONLY=False)
 class TestObservationViewsRowLevelPermissions(TestCase):
     def setUp(self):
-        self.target = TargetFactory.create()
+        self.target = SiderealTargetFactory.create()
         self.target_name = TargetNameFactory.create(target=self.target)
         self.observation_record = ObservingRecordFactory.create(
             target_id=self.target.id,
@@ -186,39 +189,39 @@ class TestObservationGroupViews(TestCase):
 
 
 @override_settings(TOM_FACILITY_CLASSES=['tom_observations.tests.utils.FakeRoboticFacility'])
-class TestObservingStrategyViews(TestCase):
+class TestObservationTemplateViews(TestCase):
     def setUp(self):
-        self.observing_strategy = ObservingStrategyFactory.create(name='Test Strategy')
+        self.observation_template = ObservationTemplateFactory.create(name='Test Template')
         self.user = User.objects.create_user(username='test', password='test')
         self.client.force_login(self.user)
 
-    def test_observing_strategy_list(self):
-        response = self.client.get(reverse('tom_observations:strategy-list'))
+    def test_observation_template_list(self):
+        response = self.client.get(reverse('tom_observations:template-list'))
         self.assertEqual(response.status_code, 200)
         self.assertContains(
-            response, reverse('tom_observations:strategy-update', kwargs={'pk': self.observing_strategy.id})
+            response, reverse('tom_observations:template-update', kwargs={'pk': self.observation_template.id})
         )
 
-    def test_observing_strategy_create(self):
-        response = self.client.get(reverse('tom_observations:strategy-create',
+    def test_observation_template_create(self):
+        response = self.client.get(reverse('tom_observations:template-create',
                                            kwargs={'facility': 'FakeRoboticFacility'}))
-        self.assertContains(response, 'Strategy name')
+        self.assertContains(response, 'Template name')
 
-    def test_observing_strategy_delete(self):
-        response = self.client.post(reverse('tom_observations:strategy-delete',
-                                    args=(self.observing_strategy.id,)),
+    def test_observation_template_delete(self):
+        response = self.client.post(reverse('tom_observations:template-delete',
+                                    args=(self.observation_template.id,)),
                                     follow=True)
-        self.assertRedirects(response, reverse('tom_observations:strategy-list'), status_code=302)
-        self.assertFalse(ObservingStrategy.objects.filter(pk=self.observing_strategy.id).exists())
+        self.assertRedirects(response, reverse('tom_observations:template-list'), status_code=302)
+        self.assertFalse(ObservationTemplate.objects.filter(pk=self.observation_template.id).exists())
 
 
 class TestUpdatingObservations(TestCase):
     def setUp(self):
-        self.t1 = TargetFactory.create()
+        self.t1 = SiderealTargetFactory.create()
         self.or1 = ObservingRecordFactory.create(target_id=self.t1.id, facility='FakeRoboticFacility', status='PENDING')
         self.or2 = ObservingRecordFactory.create(target_id=self.t1.id, status='COMPLETED')
         self.or3 = ObservingRecordFactory.create(target_id=self.t1.id, facility='FakeRoboticFacility', status='PENDING')
-        self.t2 = TargetFactory.create()
+        self.t2 = SiderealTargetFactory.create()
         self.or4 = ObservingRecordFactory.create(target_id=self.t2.id, status='PENDING')
 
     # Tests that only 2 of the three created observing records are updated, as
