@@ -24,7 +24,9 @@ from guardian.mixins import PermissionListMixin
 from tom_common.hints import add_hint
 from tom_common.mixins import Raise403PermissionRequiredMixin
 from tom_dataproducts.forms import AddProductToGroupForm, DataProductUploadForm
-from tom_observations.facility import get_service_class, get_service_classes, BaseManualObservationFacility
+from tom_observations.cadence import CadenceForm, get_cadence_strategy
+from tom_observations.facility import get_service_class, get_service_classes
+from tom_observations.facility import BaseManualObservationFacility
 from tom_observations.forms import AddExistingObservationForm
 from tom_observations.models import ObservationRecord, ObservationGroup, ObservationTemplate, DynamicCadence
 from tom_targets.models import Target
@@ -109,6 +111,7 @@ class ObservationListView(FilterView):
         return super().get(request, *args, **kwargs)
 
 
+# TODO: Ensure this template includes the ApplyObservationTemplate form at the top
 class ObservationCreateView(LoginRequiredMixin, FormView):
     """
     View for creation/submission of an observation. Requires authentication.
@@ -154,6 +157,12 @@ class ObservationCreateView(LoginRequiredMixin, FormView):
         """
         return get_service_class(self.get_facility())
 
+    def get_cadence_strategy_form(self):
+        cadence_strategy = self.request.GET.get('cadence_strategy')
+        if not cadence_strategy:
+            return CadenceForm
+        return get_cadence_strategy(cadence_strategy).form
+
     def get_context_data(self, **kwargs):
         """
         Adds the available observation types for the observing facility to the context object.
@@ -167,12 +176,14 @@ class ObservationCreateView(LoginRequiredMixin, FormView):
         # reloaded due to form errors, only repopulate the form that was submitted.
         observation_type_choices = []
         initial = self.get_initial()
-        for k, v in self.get_facility_class().observation_forms.items():
-            form_data = {**initial, **{'observation_type': k}}
+        for observation_type, observation_form_class in self.get_facility_class().observation_forms.items():
+            form_data = {**initial, **{'observation_type': observation_type}}
             # Repopulate the appropriate form with form data if the original submission was invalid
-            if k == self.request.POST.get('observation_type'):
+            if observation_type == self.request.POST.get('observation_type'):
                 form_data.update(**self.request.POST.dict())
-            observation_type_choices.append((k, v(initial=form_data)))
+            observation_form_class = type(f'Composite{observation_type}Form',
+                                          (self.get_cadence_strategy_form(), observation_form_class), {})
+            observation_type_choices.append((observation_type, observation_form_class(initial=form_data)))
         context['observation_type_choices'] = observation_type_choices
 
         # Ensure correct tab is active if submission is unsuccessful
@@ -194,7 +205,10 @@ class ObservationCreateView(LoginRequiredMixin, FormView):
             observation_type = self.request.GET.get('observation_type')
         elif self.request.method == 'POST':
             observation_type = self.request.POST.get('observation_type')
-        return self.get_facility_class()().get_form(observation_type)
+        form_class = type(f'Composite{observation_type}Form',
+                          (self.get_facility_class()().get_form(observation_type), self.get_cadence_strategy_form()),
+                          {})
+        return form_class
 
     def get_form(self):
         """
@@ -203,7 +217,6 @@ class ObservationCreateView(LoginRequiredMixin, FormView):
         :returns: observation form
         :rtype: subclass of GenericObservationForm
         """
-
         form = super().get_form()
         if not settings.TARGET_PERMISSIONS_ONLY:
             form.fields['groups'].queryset = self.request.user.groups.all()
@@ -228,6 +241,13 @@ class ObservationCreateView(LoginRequiredMixin, FormView):
         initial.update(self.request.GET.dict())
         return initial
 
+    def post(self, request, *args, **kwargs):
+        form = self.get_form()
+        if form.is_valid():
+            return self.form_valid(form)
+        else:
+            return self.form_invalid(form)
+
     def form_valid(self, form):
         """
         Runs after form validation. Submits the observation to the desired facility and creates an associated
@@ -267,10 +287,14 @@ class ObservationCreateView(LoginRequiredMixin, FormView):
 
             # TODO: Add a test case that includes a dynamic cadence submission
             if form.cleaned_data.get('cadence_strategy'):
+                cadence_parameters = {}
+                cadence_form = get_cadence_strategy(form.cleaned_data.get('cadence_strategy')).form
+                for field in cadence_form().cadence_fields:
+                    cadence_parameters[field] = form.cleaned_data.get(field)
                 DynamicCadence.objects.create(
                     observation_group=observation_group,
                     cadence_strategy=form.cleaned_data.get('cadence_strategy'),
-                    cadence_parameters={'cadence_frequency': form.cleaned_data.get('cadence_frequency')},
+                    cadence_parameters=cadence_parameters,
                     active=True
                 )
 
@@ -537,7 +561,7 @@ class ObservationTemplateCreateView(FormView):
         if not facility_name:
             raise ValueError('Must provide a facility name')
 
-        # TODO: modify this to work with both LCO forms
+        # TODO: modify this to work with all LCO forms
         return get_service_class(facility_name)().get_template_form(None)
 
     def get_form(self, form_class=None):
