@@ -10,7 +10,8 @@ from django.contrib.auth.mixins import LoginRequiredMixin
 from django.contrib.auth.models import Group
 from django.core.management import call_command
 from django.db import transaction
-from django.http import QueryDict, StreamingHttpResponse
+from django.db.models import Q
+from django.http import HttpResponseRedirect, QueryDict, StreamingHttpResponse
 from django.forms import HiddenInput
 from django.shortcuts import redirect
 from django.urls import reverse_lazy, reverse
@@ -19,7 +20,7 @@ from django.utils.safestring import mark_safe
 from django.views.generic.edit import CreateView, UpdateView, DeleteView
 from django.views.generic.detail import DetailView
 from django.views.generic.list import ListView
-from django.views.generic import TemplateView, View
+from django.views.generic import RedirectView, TemplateView, View
 from django_filters.views import FilterView
 
 from guardian.mixins import PermissionListMixin
@@ -28,16 +29,17 @@ from guardian.shortcuts import get_objects_for_user, get_groups_with_perms, assi
 from tom_common.hints import add_hint
 from tom_common.hooks import run_hook
 from tom_common.mixins import Raise403PermissionRequiredMixin
-from tom_observations.observing_strategy import RunStrategyForm
-from tom_observations.models import ObservingStrategy
-from tom_targets.models import Target, TargetList
+from tom_observations.observation_template import ApplyObservationTemplateForm
+from tom_observations.models import ObservationTemplate
+from tom_targets.filters import TargetFilter
 from tom_targets.forms import (
     SiderealTargetCreateForm, NonSiderealTargetCreateForm, TargetExtraFormset, TargetNamesFormset
 )
+from tom_targets.groups import (
+    add_all_to_grouping, add_selected_to_grouping, remove_all_from_grouping, remove_selected_from_grouping
+)
+from tom_targets.models import Target, TargetList
 from tom_targets.utils import import_targets, export_targets
-from tom_targets.filters import TargetFilter
-from tom_targets.groups import add_all_to_grouping, add_selected_to_grouping
-from tom_targets.groups import remove_all_from_grouping, remove_selected_from_grouping
 
 logger = logging.getLogger(__name__)
 
@@ -71,6 +73,26 @@ class TargetListView(PermissionListMixin, FilterView):
         return context
 
 
+class TargetNameSearchView(RedirectView):
+    """
+    View for searching by target name. If the search returns one result, the view redirects to the corresponding
+    TargetDetailView. Otherwise, the view redirects to the TargetListView.
+    """
+
+    def get(self, request, *args, **kwargs):
+        target_name = self.kwargs['name']
+        # Tests fail without distinct but it works in practice, it is unclear as to why
+        # The Django query planner shows different results between in practice and unit tests
+        # django-guardian related querying is present in the test planner, but not in practice
+        targets = get_objects_for_user(request.user, 'tom_targets.view_target').filter(
+            Q(name__icontains=target_name) | Q(aliases__name__icontains=target_name)
+        ).distinct()
+        if targets.count() == 1:
+            return HttpResponseRedirect(reverse('targets:detail', kwargs={'pk': targets.first().id}))
+        else:
+            return HttpResponseRedirect(reverse('targets:list') + f'?name={target_name}')
+
+
 class TargetCreateView(LoginRequiredMixin, CreateView):
     """
     View for creating a Target. Requires authentication.
@@ -321,15 +343,15 @@ class TargetDetailView(Raise403PermissionRequiredMixin, DetailView):
         :rtype: dict
         """
         context = super().get_context_data(*args, **kwargs)
-        observing_strategy_form = RunStrategyForm(initial={'target': self.get_object()})
-        if any(self.request.GET.get(x) for x in ['observing_strategy', 'cadence_strategy', 'cadence_frequency']):
+        observation_template_form = ApplyObservationTemplateForm(initial={'target': self.get_object()})
+        if any(self.request.GET.get(x) for x in ['observation_template', 'cadence_strategy', 'cadence_frequency']):
             initial = {'target': self.object}
             initial.update(self.request.GET)
-            observing_strategy_form = RunStrategyForm(
+            observation_template_form = ApplyObservationTemplateForm(
                 initial=initial
             )
-        observing_strategy_form.fields['target'].widget = HiddenInput()
-        context['observing_strategy_form'] = observing_strategy_form
+        observation_template_form.fields['target'].widget = HiddenInput()
+        context['observation_template_form'] = observation_template_form
         return context
 
     def get(self, request, *args, **kwargs):
@@ -355,13 +377,16 @@ class TargetDetailView(Raise403PermissionRequiredMixin, DetailView):
                               ' the docs.</a>'))
             return redirect(reverse('tom_targets:detail', args=(target_id,)))
 
-        run_strategy_form = RunStrategyForm(request.GET)
-        if run_strategy_form.is_valid():
-            obs_strat = ObservingStrategy.objects.get(pk=run_strategy_form.cleaned_data['observing_strategy'].id)
-            params = urlencode(obs_strat.parameters_as_dict)
+        obs_template_form = ApplyObservationTemplateForm(request.GET)
+        if obs_template_form.is_valid():
+            obs_template = ObservationTemplate.objects.get(pk=obs_template_form.cleaned_data['observation_template'].id)
+            obs_template_params = obs_template.parameters_as_dict
+            obs_template_params['cadence_strategy'] = request.GET.get('cadence_strategy', '')
+            obs_template_params['cadence_frequency'] = request.GET.get('cadence_frequency', '')
+            params = urlencode(obs_template_params)
             return redirect(
                 reverse('tom_observations:create',
-                        args=(obs_strat.facility,)) + f'?target_id={self.get_object().id}&' + params)
+                        args=(obs_template.facility,)) + f'?target_id={self.get_object().id}&' + params)
 
         return super().get(request, *args, **kwargs)
 
